__all__ = [
    '__title__', '__summary__', '__uri__', '__version__', '__author__',
    '__email__', '__copyright__',
]

__title__ = 'anm'
__summary__ = 'Asyncio Implementation of Netmiko'
__uri__ = 'https://github.com/richardstrnad/anm'

__version__ = '0.1.3'

__author__ = 'Richard Strnad'
__email__ = 'richard@strnad.ch'

__copyright__ = '2018 %s' % __author__